import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

import java.util.*;

/**
 * An explosion. It starts by expanding and then collapsing. 
 * The explosion will explode other obejcts that the explosion intersects.
 * 
 * @author Poul Henriksen
 * @version 1.0.1
 */
public class Mine extends SmoothMover
{
    /** How many images should be used in the animation of the explostion */
    private final static int IMAGE_COUNT= 15;
    
    /** 
     * The images in the explosion. This is static so the images are not
     * recreated for every object (improves performance significantly).
     */
    private static GreenfootImage[] images;
    
    /** Current size of the explosion */
    private int imageNo = 0;
    
    /** How much do we increment the index in the explosion animation. */
    private int increment=1;    
    
    private boolean explode;
    private boolean solutionExplode;
    
    public Mine() {
        solutionExplode = true;
        explode = false;
        initialiseImages();
        setImage(new GreenfootImage(1, 1));        
        
    }    
    
    /** 
     * Create the images for explosion.
     */
    public synchronized static void initialiseImages() {
        if(images == null) {
            GreenfootImage baseImage = new GreenfootImage("explosion.png");
            int maxSize = baseImage.getWidth()/2;
            int delta = maxSize / (IMAGE_COUNT+1);
            int size = 0;
            images = new GreenfootImage[IMAGE_COUNT];
            for(int i=0; i < IMAGE_COUNT; i++) {
                size = size + delta;
                images[i] = new GreenfootImage(baseImage);
                images[i].scale(size, size);
            }
        }
    }
    
    public void act()
    { 
        Actor p = getOneIntersectingObject(Pipes.class);
        if(p != null && MyWorld.blowUpPipes)
        {
            Greenfoot.playSound("Explosion.wav");
            explode = true;
            getWorld().removeObject(p);
            getWorld().removeObjects(getObjectsInRange(getImage().getWidth(), Pipes.class));
        }
        if(explode)
        {
            explode();
        }
        if(MyWorld.solutionPressed && MyWorld.currentLvl == 6)
        {
            explode();
        }
        else if(MyWorld.solutionPressed && MyWorld.currentLvl == 7)
        {
            explode();
        }
        else if(MyWorld.solutionPressed && MyWorld.currentLvl == 10)
        {
            explode();
        }
    }
    
    public void explode()
    {
        if(imageNo > 0) {
            setImage(images[imageNo]);
        }

        imageNo += increment;
        if(imageNo >= IMAGE_COUNT) {
            increment = -increment;
            imageNo += increment;
        }
        
        if(imageNo <= 0) {
            setImage(new GreenfootImage(1,1));
        }
        if(imageNo <= -30) {
            getWorld().addObject(new Mine(), getX(), getY());
            if(MyWorld.currentLvl == 6 && MyWorld.solutionPressed)
            {
                MyWorld world = (MyWorld) getWorld();
                world.showSolution(MyWorld.currentLvl);
                MyWorld.solutionPressed = false;
            }
            else if(MyWorld.currentLvl == 7 && MyWorld.solutionPressed)
            {
                MyWorld world = (MyWorld) getWorld();
                world.showSolution(MyWorld.currentLvl);
                MyWorld.solutionPressed = false;
            }
             if(MyWorld.currentLvl == 10 && MyWorld.solutionPressed)
            {
                MyWorld world = (MyWorld) getWorld();
                world.showSolution(MyWorld.currentLvl);
                MyWorld.solutionPressed = false;
            }
            else
            {
                getWorld().removeObject(this);
            }
        }
    }
}